
#include <iostream>

#include <QMessageBox>

#include <kcomponentdata.h>
#include <kdebug.h>
#include <klocalizedstring.h>
#include <kkeysequencewidget.h>

#include "etwidget.h"

#include "ui_etwidget.h"

const QString Config::firstStart    = "firstStart";
const QString Config::showInContext = "showInContext";
const QString Config::shortcut      = "shortcut";
const QString Config::name          = "name";
const QString Config::interpretter  = "interpretter";
const QString Config::script        = "scriptbody";

Config::Config()
    : main("kipirc")
    , cfg(main.group(Config::pluginName()))
{}

Config::Ptr Config::config(const QString& tool)
{
    Config::Ptr cfg(new Config());

    if (!tool.isEmpty())
    {
        cfg->cfg = cfg->cfg.group(tool);
    }

    return cfg;
}


const QString Config::pluginName()
{
    return i18n("External Tools");
}


ETWidget::ETWidget(QWidget* parent, const QString& tool)
    : QWidget(parent)
    , ui_(new Ui::etwidget())
{
    ui_->setupUi(this);

    ui_->add->setIcon(QIcon::fromTheme("list-add"));
    ui_->remove->setIcon(QIcon::fromTheme("list-remove"));

    connect(ui_->name, SIGNAL(currentIndexChanged(int)), SLOT(scriptSelected(int)));
    connect(ui_->add, SIGNAL(clicked(bool)), SLOT(save()));
    connect(ui_->remove, SIGNAL(clicked(bool)), SLOT(remove()));

    update(tool);
}

ETWidget::~ETWidget()
{}

void ETWidget::update(const QString& tool)
{
    Config::Ptr cfg(Config::config());

    ui_->name->clear();

    foreach(const QString& group, cfg->cfg.groupList())
    {
        KConfigGroup toolcfg = cfg->cfg.group(group);
        ui_->name->addItem(toolcfg.readEntry<QString>(Config::name, QString()), group);

        if (group == tool)
        {
            ui_->name->setCurrentIndex(ui_->name->count() - 1);
        }
    }
}

QString ETWidget::currentTool()
{
    if (ui_->name->findText(ui_->name->currentText()) == -1)
    {
        save();
    }

    return ui_->name->itemData(ui_->name->currentIndex()).toString();
}

void ETWidget::scriptSelected(int index)
{
    const QString script = ui_->name->itemData(index).toString();
    Config::Ptr cfg(Config::config());
    cfg->cfg = cfg->cfg.group(script);

    ui_->interpret->setText(cfg->cfg.readEntry<QString>(Config::interpretter, QString()));
    ui_->script->setPlainText(cfg->cfg.readEntry<QString>(Config::script, QString()));
    ui_->context->setChecked(cfg->cfg.readEntry<bool>(Config::showInContext, false));
    ui_->shortcut->setKeySequence(cfg->cfg.readEntry<QString>(Config::shortcut, QString()));
}

void ETWidget::save()
{
    Config::Ptr cfg(Config::config());

    if (ui_->name->findText(ui_->name->currentText()) != -1)
    {
        cfg->cfg = cfg->cfg.group(ui_->name->itemData(ui_->name->currentIndex()).toString());
    }
    else
    {
        cfg->cfg = cfg->cfg.group(ui_->name->currentText());
        ui_->name->addItem(ui_->name->currentText(), ui_->name->currentText());
    }

    cfg->cfg.writeEntry(Config::name, ui_->name->currentText());
    cfg->cfg.writeEntry(Config::interpretter, ui_->interpret->text());
    cfg->cfg.writeEntry(Config::script, ui_->script->toPlainText());
    cfg->cfg.writeEntry(Config::showInContext, ui_->context->isChecked());
    cfg->cfg.writeEntry(Config::shortcut, ui_->shortcut->keySequence().toString());

    cfg->cfg.sync();
}

void ETWidget::remove()
{
    Config::Ptr cfg(Config::config());

    if (ui_->name->currentIndex() != -1)
    {
        QMessageBox::StandardButton answer =
            QMessageBox::question(this,
                                  i18n("Removing tool"),
                                  i18n("Are you sure"),
                                  QMessageBox::Ok | QMessageBox::Abort);

        if (answer != QMessageBox::Ok)
        {
            return;
        }

        cfg->cfg.deleteGroup(ui_->name->itemData(ui_->name->currentIndex()).toString());
        cfg->cfg.sync();
        ui_->name->removeItem(ui_->name->currentIndex());
    }
}

