/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.digikam.org
 *
 * Date        : 2010-11-15
 * Description : a kipi plugin to export images to Yandex.Fotki web service
 *
 * Copyright (C) 2010 by Roman Tsisyk <roman at tsisyk dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "plugin_externaltools.moc"

#include <kaction.h>
#include <kgenericfactory.h>
#include <kdebug.h>
#include <kapplication.h>
#include <kactioncollection.h>

#include <libkipi/imagecollection.h>
#include "libkipi/interface.h"

#include "etdialog.h"
#include "etrunner.h"

namespace KIPIExtenalToolsPlugin
{

K_PLUGIN_FACTORY( Factory, registerPlugin<Plugin_ExternalTools>(); )
K_EXPORT_PLUGIN ( Factory("kipiplugin_externaltools") )

Plugin_ExternalTools::Plugin_ExternalTools(QObject* const parent, const QVariantList&)
    : Plugin(Factory::componentData(), parent, "External Tools")
{
    kDebug(AREA_CODE_LOADING) << "Plugin_ExternalTools plugin loaded";
}

Plugin_ExternalTools::~Plugin_ExternalTools()
{
}

void Plugin_ExternalTools::setup(QWidget* const widget)
{
    Plugin::setup(widget);
    KIconLoader::global()->addAppDir("kipiplugin_externaltools");

    if (!interface())
    {
        kError() << "Kipi interface is null!";
        return;
    }

    if (Config::config()->cfg.readEntry<bool>(Config::firstStart, true))
    {
        Config::config()->cfg.writeEntry(Config::firstStart, false);
        firstStart();
    }

    setupActions();
}

void Plugin_ExternalTools::firstStart()
{
    Config::Ptr cfg(Config::config());

    KConfigGroup archive = cfg->cfg.group("archive");
    archive.writeEntry(Config::name, i18n("/tmp/images.tar.gz"));
    archive.writeEntry(Config::interpretter, "/bin/sh");
    archive.writeEntry(Config::script, "exec tar -czf /tmp/images.tar.gz --transform='s,.*/,,' -T -");

    cfg->cfg.sync();
}

void Plugin_ExternalTools::setupActions()
{
    setDefaultCategory(ExportPlugin);

    KAction* mainAction = new KAction(this);
    mainAction->setText(i18n("Export with &External Tools..."));
    mainAction->setIcon(KIcon("document-export"));
    mainAction->setShortcut(KShortcut(Qt::ALT + Qt::SHIFT + Qt::Key_E));
    mainAction->setEnabled(true);

    connect(mainAction, SIGNAL(triggered(bool)), this, SLOT(slotExport()));

    addAction(Config::pluginName(), mainAction);

    Config::Ptr cfg = Config::config();
    foreach(const QString tool, cfg->cfg.groupList())
    {
        KConfigGroup toolcfg = cfg->cfg.group(tool);

        if (!toolcfg.readEntry<bool>(Config::showInContext, false))
        {
            continue;
        }

        KAction* action = new KAction(this);
        action->setData(tool);
        const QString text = i18n("Export with %1 [%2]")
                             .arg(toolcfg.readEntry<QString>(Config::name, i18n("unnamed")))
                             .arg(Config::pluginName());
        action->setText(text);
        action->setIcon(KIcon("utilities-terminal"));
        action->setShortcut(toolcfg.readEntry<QString>(Config::shortcut, QString()));
        action->setEnabled(true);

        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotToolExport()));
        addAction(text, action);
    }
}

void Plugin_ExternalTools::slotExport()
{
    ETDialog dialog(kapp->activeWindow());
    dialog.exec();
}

void Plugin_ExternalTools::slotToolExport()
{
    KAction* action = qobject_cast<KAction*>(sender());
    //     ETRunner runner(this, action->data().toString(), interface()->currentSelection().images());
    //     runner.runAndBlock();
    ETDialog dialog(kapp->activeWindow(), action->data().toString());
    dialog.exec();
}


} // namespace KIPIExternalToolsPlugin


